/// <reference types="react" />
import { NextRouter as NextRouterType } from 'next/router';
import { AppRouter, LinkProps, Location, LocationChangeCallback, RouterPushOptions, UnregisterCallback } from 'onekijs-core';
export default class NextRouter extends AppRouter {
    listeners: LocationChangeCallback[];
    constructor(listeners: LocationChangeCallback[]);
    get native(): NextRouterType | null;
    back(delta?: number): void;
    forward(delta?: number): void;
    /**
     * url can be a string or an object.
     * If object, the format is the following
     * {
     *   url: string, // example: /users/1?test=1&test2#h=3&h2
     *   route: string, // example: /users/[id]
     *   pathname: string, // example: /users/1
     *   query: obj, // example: {test:1,test2:null}
     *   hash: obj // example: {h:3, h2:null}
     *   state: obj // example: {key1: 'value1'}
     * }
     */
    push(urlOrLocation: string | Location, options?: RouterPushOptions): void;
    replace(urlOrLocation: string | Location, options?: RouterPushOptions): void;
    /**
     * callback(url) where url is:
     * {
     *   url: string, // example: /users/1?test=1&test2#h=3&h2
     *   route: string, // example: /users/[id]
     *   pathname: string, // example: /users/1
     *   query: obj, // example: {test:1,test2:null}
     *   hash: obj // example: {h:3, h2:null}
     *   state: obj // example: {key1: 'value1'}
     * }
     */
    listen(callback: LocationChangeCallback): UnregisterCallback;
    onLocationChange(): void;
    sync(nextRouter: NextRouterType): void;
    getLinkComponent(props: LinkProps): JSX.Element;
    private goto;
}
